SBoM.CycloneDX.V13.Pedigree (SBoM v0.9.1)
View SourceComponent pedigree is a way to document complex supply chain scenarios where components are created, distributed, modified, redistributed, combined with other components, etc. Pedigree supports viewing this complex chain from the beginning, the end, or anywhere in the middle. It also provides a way to document variants where the exact relation may not be known.
Summary
Types
@type t() :: %SBoM.CycloneDX.V13.Pedigree{ __unknown_fields__: [Protobuf.unknown_field()], ancestors: [SBoM.CycloneDX.V13.Component.t()], commits: [SBoM.CycloneDX.V13.Commit.t()], descendants: [SBoM.CycloneDX.V13.Component.t()], notes: String.t() | nil, patches: [SBoM.CycloneDX.V13.Patch.t()], variants: [SBoM.CycloneDX.V13.Component.t()] }