SBoM.CycloneDX.V15.Step (SBoM v0.9.1)
View SourceExecutes specific commands or tools in order to accomplish its owning task as part of a sequence.
Summary
Types
@type t() :: %SBoM.CycloneDX.V15.Step{ __unknown_fields__: [Protobuf.unknown_field()], commands: [SBoM.CycloneDX.V15.Command.t()], description: String.t() | nil, name: String.t() | nil, properties: [SBoM.CycloneDX.V15.Property.t()] }