SBoM.CycloneDX.V16.ExternalReference (SBoM v0.9.1)
View SourceExternal references provide a way to document systems, sites, and information that may be relevant but are not included with the BOM. They may also establish specific relationships within or external to the BOM.
Summary
Types
@type t() :: %SBoM.CycloneDX.V16.ExternalReference{ __unknown_fields__: [Protobuf.unknown_field()], comment: String.t() | nil, hashes: [SBoM.CycloneDX.V16.Hash.t()], type: SBoM.CycloneDX.V16.ExternalReferenceType.t(), url: String.t() }