Data governance captures information regarding data ownership, stewardship, and custodianship, providing insights into the individuals or entities responsible for managing, overseeing, and safeguarding the data throughout its lifecycle.
Summary
Types
@type t() :: %SBoM.CycloneDX.V17.DataGovernance{ __unknown_fields__: [Protobuf.unknown_field()], custodians: [ SBoM.CycloneDX.V17.DataGovernance.DataGovernanceResponsibleParty.t() ], owners: [SBoM.CycloneDX.V17.DataGovernance.DataGovernanceResponsibleParty.t()], stewards: [ SBoM.CycloneDX.V17.DataGovernance.DataGovernanceResponsibleParty.t() ] }