SBoM.CycloneDX.V17.LicenseExpressionDetailed (SBoM v0.9.1)

Specifies the details and attributes related to a software license. It must be a valid SPDX license expression, along with additional properties such as license acknowledgment.

Summary

Types

t()

@type t() :: %SBoM.CycloneDX.V17.LicenseExpressionDetailed{
  __unknown_fields__: [Protobuf.unknown_field()],
  acknowledgement:
    SBoM.CycloneDX.V17.LicenseAcknowledgementEnumeration.t() | nil,
  bom_ref: String.t() | nil,
  details: [SBoM.CycloneDX.V17.LicenseExpressionDetailed.ExpressionDetails.t()],
  expression: String.t(),
  licensing: SBoM.CycloneDX.V17.Licensing.t() | nil,
  properties: [SBoM.CycloneDX.V17.Property.t()]
}