SBoM.CycloneDX.V17.LicenseExpressionDetailed.ExpressionDetails (SBoM v0.9.1)

This document specifies the details and attributes related to a software license identifier. An SPDX expression may be a compound of license identifiers. The license_identifier field serves as the key that identifies each record. Note that this key is not required to be unique, as the same license identifier could apply to multiple, different but similar license details, texts, etc.

Summary

Types

t()

@type t() :: %SBoM.CycloneDX.V17.LicenseExpressionDetailed.ExpressionDetails{
  __unknown_fields__: [Protobuf.unknown_field()],
  bom_ref: String.t() | nil,
  license_identifier: String.t(),
  text: SBoM.CycloneDX.V17.AttachedText.t() | nil,
  url: String.t() | nil
}