SBoM.CycloneDX.V16.Advisory (SBoM v0.9.1)
View SourceTitle and location where advisory information can be obtained. An advisory is a notification of a threat to a component, service, or system.
Summary
Types
@type t() :: %SBoM.CycloneDX.V16.Advisory{ __unknown_fields__: [Protobuf.unknown_field()], title: String.t() | nil, url: String.t() }