SBoM.CycloneDX.V16.License (SBoM v0.9.1)
View SourceSpecifies the details and attributes related to a software license. It can either include a valid SPDX license identifier or a named license, along with additional properties such as license acknowledgment, comprehensive commercial licensing information, and the full text of the license.
Summary
Types
@type t() :: %SBoM.CycloneDX.V16.License{ __unknown_fields__: [Protobuf.unknown_field()], acknowledgement: SBoM.CycloneDX.V16.LicenseAcknowledgementEnumeration.t() | nil, bom_ref: String.t() | nil, license: {:id, String.t()} | {:name, String.t()} | nil, licensing: SBoM.CycloneDX.V16.Licensing.t() | nil, properties: [SBoM.CycloneDX.V16.Property.t()], text: SBoM.CycloneDX.V16.AttachedText.t() | nil, url: String.t() | nil }