SBoM.CycloneDX.V17.TlpClassification (SBoM v0.9.1)
View SourceTraffic Light Protocol (TLP) is a classification system for identifying the potential risk associated with artefact, including whether it is subject to certain types of legal, financial, or technical threats. Refer to https://www.first.org/tlp/ for further information. The default classification is "CLEAR"
Summary
Types
@type t() :: integer() | :TLP_CLASSIFICATION_CLEAR | :TLP_CLASSIFICATION_GREEN | :TLP_CLASSIFICATION_AMBER | :TLP_CLASSIFICATION_AMBER_AND_STRICT | :TLP_CLASSIFICATION_RED